==> spip_3.2.11.orig.tar.xz: plugins-dist/mots/lang/mots_vi.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=vi
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Nhóm quan trọng</b>: đề nghị bạn nên chọn một từ then chốt trong nhóm này.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'quản trị viên',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'tác giả',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'Độc giả lúc gửi góp ý trên diễn đàn.',

	// I
	'icone_creation_groupe_mots' => 'Thêm NHÓM từ mới  ',
	'icone_creation_mots_cles' => 'Thêm từ then chốt mới ',
	'icone_modif_groupe_mots' => 'Sửa NHÓM từ này',
	'icone_mots_cles' => 'Từ then chốt',
	'icone_supprimer_groupe_mots' => 'Xóa NHÓM từ này ',
	'icone_voir_tous_mots_cles' => 'Xem những từ then chốt',
	'info_articles_lies_mot' => 'Những bài liên hệ đến từ then chốt này',
	'info_changer_nom_groupe' => 'Đổi tên của nhóm này:',
	'info_creation_mots_cles' => 'Thêm bớt, sửa đổi, sắp xếp các từ then chốt của website',
	'info_dans_groupe' => 'Trong nhóm:',
	'info_delet_mots_cles' => 'Bạn yêu cầu xóa từ then chốt
<b>@titre_mot@</b> (@type_mot@). Từ then chốt này có nối qua
<b>@texte_lie@</b> bạn phải xác nhận quyết định này:', # MODIF
	'info_groupe_important' => 'Nhóm quan trọng',
	'info_mots_cles' => 'Các từ then chốt',
	'info_mots_cles_association' => 'Các từ then chốt trong nhóm này có thể được dùng cho:',
	'info_oui_suppression_mot_cle' => 'Tôi muốn xóa luôn từ then chốt này.',
	'info_question_mots_cles' => 'Bạn có muốn dùng từ then chốt trong website? ',
	'info_qui_attribue_mot_cle' => 'Những người có quyền ấn định các từ then chốt này:',
	'info_retirer_mot' => 'Xóa từ then chốt này',
	'info_retirer_mots' => 'Xóa hết tất cả từ then chốt',
	'info_rubriques_liees_mot' => 'Đề mục có liên hệ với từ then chốt này',
	'info_selection_un_seul_mot_cle' => 'Bạn có thể chọn <b>một từ then chốt duy nhất</b> mỗi lần trong nhóm này.', # MODIF
	'info_supprimer_mot' => 'xóa từ then chốt này',
	'info_titre_mot_cle' => 'Tên hay tựa của từ then chốt này',
	'info_un_mot' => 'Mỗi lần một từ then chốt thôi',
	'item_ajout_mots_cles' => 'Cho phép thêm các từ then chốt vào diễn đàn',
	'item_non_ajout_mots_cles' => 'Không cho phép thêm các từ then chốt vào diễn đàn',
	'item_non_utiliser_config_groupe_mots_cles' => 'Không dùng cấu hình cao cấp của nhóm từ then chốt',
	'item_non_utiliser_mots_cles' => 'Không dùng từ then chốt',
	'item_utiliser_config_groupe_mots_cles' => 'Dùng cấu hình cao cấp của nhóm từ then chốt',
	'item_utiliser_mots_cles' => 'Dùng từ then chốt',

	// L
	'logo_mot_cle' => 'LOGO CỦA TỪ THEN CHỐT',

	// T
	'texte_config_groupe_mots_cles' => 'Bạn có muốn mở đặc điểm cấu hình cao cấp của nhóm từ then chốt, bằng cách, lấy thí dụ như một chữ đặc thù cho mỗi nhóm có thể được chọn, nhóm quan trọng...? ', # MODIF
	'texte_mots_cles' => 'Từ then chốt cho phép bạn lập mối liên hệ theo đề tài giữa các bài với nhau, bất kể chúng ở trong đề mục nào. Như thế việc di chuyển trong webiste phong phú hơn hoặc bạn dùng những đặc tính này để thay đổi bài vở trong khuôn mẫu.',
	'texte_mots_cles_dans_forum' => 'Bạn có muốn cho phép dùng các từ then chốt để khách chọn, trong các diễn đàn công cộng? (Cảnh báo: đặc tính này khá phức tạp để sử dụng cho đúng.)',
	'texte_nouveau_mot' => 'Từ then chốt mới',
	'titre_config_groupe_mots_cles' => 'Cấu hình các nhóm từ then chốt',
	'titre_gauche_mots_edit' => 'SỐ THỨ TỰ CỦA TỪ THEN CHỐT:',
	'titre_mots_cles_dans_forum' => 'Những từ then chốt trong diễn đàn công cộng',
	'titre_mots_tous' => 'Từ then chốt',
	'titre_nouveau_groupe' => 'Nhóm mới',
	'titre_page_mots_tous' => 'Từ then chốt'
);

==> spip_4.4.8+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_vi.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=vi
// ** ne pas modifier le fichier **

return [

	// A
	'avis_conseil_selection_mot_cle' => '<b>Nhóm quan trọng</b>: đề nghị bạn nên chọn một từ then chốt trong nhóm này.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'quản trị viên',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'tác giả',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'Độc giả lúc gửi góp ý trên diễn đàn.',

	// I
	'icone_creation_groupe_mots' => 'Thêm NHÓM từ mới  ',
	'icone_creation_mots_cles' => 'Thêm từ then chốt mới ',
	'icone_modif_groupe_mots' => 'Sửa NHÓM từ này',
	'icone_mots_cles' => 'Từ then chốt',
	'icone_supprimer_groupe_mots' => 'Xóa NHÓM từ này ',
	'icone_voir_tous_mots_cles' => 'Xem những từ then chốt',
	'info_articles_lies_mot' => 'Những bài liên hệ đến từ then chốt này',
	'info_changer_nom_groupe' => 'Đổi tên của nhóm này:',
	'info_creation_mots_cles' => 'Thêm bớt, sửa đổi, sắp xếp các từ then chốt của website',
	'info_dans_groupe' => 'Trong nhóm:',
	'info_delet_mots_cles' => 'Bạn yêu cầu xóa từ then chốt
<b>@titre_mot@</b> (@type_mot@). Từ then chốt này có nối qua
<b>@texte_lie@</b> bạn phải xác nhận quyết định này:', # MODIF
	'info_groupe_important' => 'Nhóm quan trọng',
	'info_mots_cles' => 'Các từ then chốt',
	'info_mots_cles_association' => 'Các từ then chốt trong nhóm này có thể được dùng cho:',
	'info_oui_suppression_mot_cle' => 'Tôi muốn xóa luôn từ then chốt này.',
	'info_question_mots_cles' => 'Bạn có muốn dùng từ then chốt trong website? ',
	'info_qui_attribue_mot_cle' => 'Những người có quyền ấn định các từ then chốt này:',
	'info_retirer_mot' => 'Xóa từ then chốt này',
	'info_retirer_mots' => 'Xóa hết tất cả từ then chốt',
	'info_rubriques_liees_mot' => 'Đề mục có liên hệ với từ then chốt này',
	'info_selection_un_seul_mot_cle' => 'Bạn có thể chọn <b>một từ then chốt duy nhất</b> mỗi lần trong nhóm này.', # MODIF
	'info_supprimer_mot' => 'xóa từ then chốt này',
	'info_titre_mot_cle' => 'Tên hay tựa của từ then chốt này',
	'info_un_mot' => 'Mỗi lần một từ then chốt thôi',
	'item_ajout_mots_cles' => 'Cho phép thêm các từ then chốt vào diễn đàn',
	'item_non_ajout_mots_cles' => 'Không cho phép thêm các từ then chốt vào diễn đàn',
	'item_non_utiliser_config_groupe_mots_cles' => 'Không dùng cấu hình cao cấp của nhóm từ then chốt',
	'item_non_utiliser_mots_cles' => 'Không dùng từ then chốt',
	'item_utiliser_config_groupe_mots_cles' => 'Dùng cấu hình cao cấp của nhóm từ then chốt',
	'item_utiliser_mots_cles' => 'Dùng từ then chốt',

	// L
	'logo_mot_cle' => 'LOGO CỦA TỪ THEN CHỐT',

	// T
	'texte_config_groupe_mots_cles' => 'Bạn có muốn mở đặc điểm cấu hình cao cấp của nhóm từ then chốt, bằng cách, lấy thí dụ như một chữ đặc thù cho mỗi nhóm có thể được chọn, nhóm quan trọng...? ', # MODIF
	'texte_mots_cles' => 'Từ then chốt cho phép bạn lập mối liên hệ theo đề tài giữa các bài với nhau, bất kể chúng ở trong đề mục nào. Như thế việc di chuyển trong webiste phong phú hơn hoặc bạn dùng những đặc tính này để thay đổi bài vở trong khuôn mẫu.',
	'texte_mots_cles_dans_forum' => 'Bạn có muốn cho phép dùng các từ then chốt để khách chọn, trong các diễn đàn công cộng? (Cảnh báo: đặc tính này khá phức tạp để sử dụng cho đúng.)',
	'texte_nouveau_mot' => 'Từ then chốt mới',
	'titre_config_groupe_mots_cles' => 'Cấu hình các nhóm từ then chốt',
	'titre_gauche_mots_edit' => 'SỐ THỨ TỰ CỦA TỪ THEN CHỐT:',
	'titre_mots_cles_dans_forum' => 'Những từ then chốt trong diễn đàn công cộng',
	'titre_mots_tous' => 'Từ then chốt',
	'titre_nouveau_groupe' => 'Nhóm mới',
	'titre_page_mots_tous' => 'Từ then chốt',
];
